You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tapestry.apache.org by hl...@apache.org on 2007/10/28 20:29:59 UTC

svn commit: r589400 - /tapestry/tapestry5/trunk/tapestry-ioc/src/main/java/org/apache/tapestry/ioc/annotations/Primary.java

Author: hlship
Date: Sun Oct 28 12:29:57 2007
New Revision: 589400

URL: http://svn.apache.org/viewvc?rev=589400&view=rev
Log:
TAPESTRY-1828: Convert uses of @InjectService to be @Inject plus a marker annotation

Modified:
    tapestry/tapestry5/trunk/tapestry-ioc/src/main/java/org/apache/tapestry/ioc/annotations/Primary.java

Modified: tapestry/tapestry5/trunk/tapestry-ioc/src/main/java/org/apache/tapestry/ioc/annotations/Primary.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-ioc/src/main/java/org/apache/tapestry/ioc/annotations/Primary.java?rev=589400&r1=589399&r2=589400&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-ioc/src/main/java/org/apache/tapestry/ioc/annotations/Primary.java (original)
+++ tapestry/tapestry5/trunk/tapestry-ioc/src/main/java/org/apache/tapestry/ioc/annotations/Primary.java Sun Oct 28 12:29:57 2007
@@ -23,14 +23,13 @@
 import java.lang.annotation.Target;
 
 import org.apache.tapestry.ioc.services.ChainBuilder;
-
-import apple.awt.StrategyBufferImage;
+import org.apache.tapestry.ioc.services.StrategyBuilder;
 
 /**
  * Marker annotation used to denote a service that is the primary instance of some common interface.
  * This is often used when a service is a {@linkplain ChainBuilder chain of command} or
  * {@linkplain StrategyBufferImage strategy-based} and, therefore, many services will implement the
  * same interface.
  */
 @Target(
 { PARAMETER, FIELD })
@@ -23,14 +23,13 @@
  * Marker annotation used to denote a service that is the primary instance of some common interface.
  * This is often used when a service is a {@linkplain ChainBuilder chain of command} or
- * {@linkplain StrategyBufferImage strategy-based} and, therefore, many services will implement the
- * same interface.
+ * {@linkplain StrategyBuilder strategy-based} and, therefore, many services will implement the same
+ * interface.
  */
 @Target(